package main

import (
	"bytes"
	"crypto/tls"
	"fmt"
	"io"
	"net/http"
	"net/url"
	"os"
)

func testGet() {
	url := "https://www.xiexianbin.cn"

	resp, err := http.Get(url)
	if err != nil {
		fmt.Println(err)
		return
	}

	buf := bytes.NewBuffer(nil)

	buf.WriteString(fmt.Sprintf("%s %s\r\n", resp.Proto, resp.Status))
	for k, v := range resp.Header {
		buf.WriteString(fmt.Sprintf("%s: %s\r\n", k, v))
	}
	buf.WriteString("\r\n")
	io.Copy(buf, resp.Body)

	fmt.Println(buf.String())
}

// self sign ca
func testGet2() {
	u := "https://s1.dddd.dev"
	req, err := http.NewRequest("GET", u, nil)
	if err != nil {
		fmt.Println(err)
		return
	}

	transport := http.Transport{
		TLSClientConfig: &tls.Config{
			InsecureSkipVerify: true,
		},
	}

	client := &http.Client{Transport: &transport}
	//client.Get()
	//client.Post()
	resp, err := client.Do(req)
	if err != nil {
		fmt.Println(err)
		return
	}
	fmt.Println(resp.StatusCode)
	io.Copy(os.Stdout, resp.Body)
}

func testPost() {
	// curl -v -XPOST "https://api.github.com/gists" -H "content-type: application/json" -H "Accept: application/vnd.github.v3+json" -d "{}"
	url := "https://api.github.com/gists"
	body := bytes.NewReader([]byte("{}"))
	resp, err := http.Post(url, "application/json", body)
	if err != nil {
		return
	}

	buf := bytes.NewBuffer(nil)

	buf.WriteString(fmt.Sprintf("%s %s\r\n", resp.Proto, resp.Status))
	for k, v := range resp.Header {
		buf.WriteString(fmt.Sprintf("%s: %s\r\n", k, v))
	}
	buf.WriteString("\r\n")
	io.Copy(buf, resp.Body)

	fmt.Println(buf.String())
}

func testPostForm() {
	// curl -v -XPOST "https://api.github.com/gists" -H "content-type: application/json" -H "Accept: application/vnd.github.v3+json" -d "{}"
	u := "https://api.github.com/gists"
	//var data url.Values = url.Values{}
	data := make(url.Values)
	data.Add("username", "xianbin")
	data.Add("password", "123456")
	resp, err := http.PostForm(u, data)
	if err != nil {
		return
	}

	buf := bytes.NewBuffer(nil)

	buf.WriteString(fmt.Sprintf("%s %s\r\n", resp.Proto, resp.Status))
	for k, v := range resp.Header {
		buf.WriteString(fmt.Sprintf("%s: %s\r\n", k, v))
	}
	buf.WriteString("\r\n")
	io.Copy(buf, resp.Body)

	fmt.Println(buf.String())
}

func testDelete() {
	u := "https://api.github.com/gists"
	req, err := http.NewRequest("DELETE", u, nil)
	if err != nil {
		fmt.Println(err)
		return
	}
	client := &http.Client{Transport: http.DefaultTransport}
	//client.Get()
	//client.Post()
	resp, err := client.Do(req)
	if err != nil {
		fmt.Println(err)
		return
	}
	fmt.Println(resp.StatusCode, resp.Body)
}

func main() {
	testGet()
	testGet2()
	testPost()
	testPostForm()
	testDelete()
}
